# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Backup'
prefix = 'backup'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateBackupPlan = Action('CreateBackupPlan')
CreateBackupSelection = Action('CreateBackupSelection')
CreateBackupVault = Action('CreateBackupVault')
DeleteBackupPlan = Action('DeleteBackupPlan')
DeleteBackupSelection = Action('DeleteBackupSelection')
DeleteBackupVault = Action('DeleteBackupVault')
DeleteBackupVaultAccessPolicy = Action('DeleteBackupVaultAccessPolicy')
DeleteBackupVaultNotifications = Action('DeleteBackupVaultNotifications')
DeleteRecoveryPoint = Action('DeleteRecoveryPoint')
DescribeBackupJob = Action('DescribeBackupJob')
DescribeBackupVault = Action('DescribeBackupVault')
DescribeProtectedResource = Action('DescribeProtectedResource')
DescribeRecoveryPoint = Action('DescribeRecoveryPoint')
DescribeRestoreJob = Action('DescribeRestoreJob')
ExportBackupPlanTemplate = Action('ExportBackupPlanTemplate')
GetBackupPlan = Action('GetBackupPlan')
GetBackupPlanFromJSON = Action('GetBackupPlanFromJSON')
GetBackupPlanFromTemplate = Action('GetBackupPlanFromTemplate')
GetBackupSelection = Action('GetBackupSelection')
GetBackupVaultAccessPolicy = Action('GetBackupVaultAccessPolicy')
GetBackupVaultNotifications = Action('GetBackupVaultNotifications')
GetRecoveryPointRestoreMetadata = \
    Action('GetRecoveryPointRestoreMetadata')
GetSupportedResourceTypes = Action('GetSupportedResourceTypes')
ListBackupJobs = Action('ListBackupJobs')
ListBackupPlanTemplates = Action('ListBackupPlanTemplates')
ListBackupPlanVersions = Action('ListBackupPlanVersions')
ListBackupPlans = Action('ListBackupPlans')
ListBackupSelections = Action('ListBackupSelections')
ListBackupVaults = Action('ListBackupVaults')
ListProtectedResources = Action('ListProtectedResources')
ListRecoveryPointsByBackupVault = \
    Action('ListRecoveryPointsByBackupVault')
ListRecoveryPointsByResource = Action('ListRecoveryPointsByResource')
ListRestoreJobs = Action('ListRestoreJobs')
ListTags = Action('ListTags')
PutBackupVaultAccessPolicy = Action('PutBackupVaultAccessPolicy')
PutBackupVaultNotifications = Action('PutBackupVaultNotifications')
StartBackupJob = Action('StartBackupJob')
StartRestoreJob = Action('StartRestoreJob')
StopBackupJob = Action('StopBackupJob')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateBackupPlan = Action('UpdateBackupPlan')
UpdateRecoveryPointLifecycle = Action('UpdateRecoveryPointLifecycle')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS SSO Directory'
prefix = 'sso-directory'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddMemberToGroup = Action('AddMemberToGroup')
CompleteVirtualMfaDeviceRegistration = \
    Action('CompleteVirtualMfaDeviceRegistration')
CreateAlias = Action('CreateAlias')
CreateGroup = Action('CreateGroup')
CreateUser = Action('CreateUser')
DeleteGroup = Action('DeleteGroup')
DeleteMfaDeviceForUser = Action('DeleteMfaDeviceForUser')
DeleteUser = Action('DeleteUser')
DescribeDirectory = Action('DescribeDirectory')
DescribeGroups = Action('DescribeGroups')
DescribeUsers = Action('DescribeUsers')
DisableUser = Action('DisableUser')
EnableUser = Action('EnableUser')
ListGroupsForUser = Action('ListGroupsForUser')
ListMembersInGroup = Action('ListMembersInGroup')
ListMfaDevicesForUser = Action('ListMfaDevicesForUser')
RemoveMemberFromGroup = Action('RemoveMemberFromGroup')
SearchGroups = Action('SearchGroups')
SearchUsers = Action('SearchUsers')
StartVirtualMfaDeviceRegistration = \
    Action('StartVirtualMfaDeviceRegistration')
UpdateGroup = Action('UpdateGroup')
UpdatePassword = Action('UpdatePassword')
UpdateUser = Action('UpdateUser')
VerifyEmail = Action('VerifyEmail')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Machine Learning'
prefix = 'machinelearning'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddTags = Action('AddTags')
CreateBatchPrediction = Action('CreateBatchPrediction')
CreateDataSourceFromRDS = Action('CreateDataSourceFromRDS')
CreateDataSourceFromRedshift = Action('CreateDataSourceFromRedshift')
CreateDataSourceFromS3 = Action('CreateDataSourceFromS3')
CreateEvaluation = Action('CreateEvaluation')
CreateMLModel = Action('CreateMLModel')
CreateRealtimeEndpoint = Action('CreateRealtimeEndpoint')
DeleteBatchPrediction = Action('DeleteBatchPrediction')
DeleteDataSource = Action('DeleteDataSource')
DeleteEvaluation = Action('DeleteEvaluation')
DeleteMLModel = Action('DeleteMLModel')
DeleteRealtimeEndpoint = Action('DeleteRealtimeEndpoint')
DeleteTags = Action('DeleteTags')
DescribeBatchPredictions = Action('DescribeBatchPredictions')
DescribeDataSources = Action('DescribeDataSources')
DescribeEvaluations = Action('DescribeEvaluations')
DescribeMLModels = Action('DescribeMLModels')
DescribeTags = Action('DescribeTags')
GetBatchPrediction = Action('GetBatchPrediction')
GetDataSource = Action('GetDataSource')
GetEvaluation = Action('GetEvaluation')
GetMLModel = Action('GetMLModel')
Predict = Action('Predict')
UpdateBatchPrediction = Action('UpdateBatchPrediction')
UpdateDataSource = Action('UpdateDataSource')
UpdateEvaluation = Action('UpdateEvaluation')
UpdateMLModel = Action('UpdateMLModel')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS IoT SiteWise'
prefix = 'iotsitewise'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateGatewaySink = Action('AssociateGatewaySink')
AssociateGatewaySource = Action('AssociateGatewaySource')
AssociateViewEntities = Action('AssociateViewEntities')
CreateAsset = Action('CreateAsset')
CreateAssetTemplate = Action('CreateAssetTemplate')
CreateGateway = Action('CreateGateway')
CreateGroup = Action('CreateGroup')
CreateMeasurementDataStore = Action('CreateMeasurementDataStore')
CreateMetricType = Action('CreateMetricType')
CreateView = Action('CreateView')
DeleteAsset = Action('DeleteAsset')
DeleteAssetTemplate = Action('DeleteAssetTemplate')
DeleteGateway = Action('DeleteGateway')
DeleteGroup = Action('DeleteGroup')
DeleteMeasurementDataStore = Action('DeleteMeasurementDataStore')
DeleteMetricType = Action('DeleteMetricType')
DeleteView = Action('DeleteView')
DeregisterViewEntities = Action('DeregisterViewEntities')
DescribeAssetTemplates = Action('DescribeAssetTemplates')
DescribeAssets = Action('DescribeAssets')
DescribeGateways = Action('DescribeGateways')
DescribeGroups = Action('DescribeGroups')
DescribeMeasurementDataStores = Action('DescribeMeasurementDataStores')
DescribeMetricTypes = Action('DescribeMetricTypes')
DescribeViews = Action('DescribeViews')
DisassociateGatewaySink = Action('DisassociateGatewaySink')
DisassociateGatewaySource = Action('DisassociateGatewaySource')
DisassociateViewEntities = Action('DisassociateViewEntities')
GetMeasurementData = Action('GetMeasurementData')
GetMetricData = Action('GetMetricData')
ListAssetTemplates = Action('ListAssetTemplates')
ListAssets = Action('ListAssets')
ListGateways = Action('ListGateways')
ListGroups = Action('ListGroups')
ListMeasurementDataStores = Action('ListMeasurementDataStores')
ListMeasurementDataStreams = Action('ListMeasurementDataStreams')
ListMetricTypes = Action('ListMetricTypes')
ListViewEntities = Action('ListViewEntities')
ListViews = Action('ListViews')
RegisterViewEntities = Action('RegisterViewEntities')
UpdateAsset = Action('UpdateAsset')
UpdateAssetTemplate = Action('UpdateAssetTemplate')
UpdateGateway = Action('UpdateGateway')
UpdateGroup = Action('UpdateGroup')
UpdateMeasurementDataStore = Action('UpdateMeasurementDataStore')
UpdateView = Action('UpdateView')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Code Signing for Amazon FreeRTOS'
prefix = 'signer'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CancelSigningProfile = Action('CancelSigningProfile')
DescribeSigningJob = Action('DescribeSigningJob')
GetSigningPlatform = Action('GetSigningPlatform')
GetSigningProfile = Action('GetSigningProfile')
ListSigningJobs = Action('ListSigningJobs')
ListSigningPlatforms = Action('ListSigningPlatforms')
ListSigningProfiles = Action('ListSigningProfiles')
PutSigningProfile = Action('PutSigningProfile')
StartSigningJob = Action('StartSigningJob')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Chime'
prefix = 'chime'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptDelegate = Action('AcceptDelegate')
ActivateUsers = Action('ActivateUsers')
AddDomain = Action('AddDomain')
AddOrUpdateGroups = Action('AddOrUpdateGroups')
AssociatePhoneNumberWithUser = Action('AssociatePhoneNumberWithUser')
AssociatePhoneNumbersWithVoiceConnector = \
    Action('AssociatePhoneNumbersWithVoiceConnector')
AssociatePhoneNumbersWithVoiceConnectorGroup = \
    Action('AssociatePhoneNumbersWithVoiceConnectorGroup')
AuthorizeDirectory = Action('AuthorizeDirectory')
BatchDeletePhoneNumber = Action('BatchDeletePhoneNumber')
BatchSuspendUser = Action('BatchSuspendUser')
BatchUnsuspendUser = Action('BatchUnsuspendUser')
BatchUpdatePhoneNumber = Action('BatchUpdatePhoneNumber')
BatchUpdateUser = Action('BatchUpdateUser')
ConnectDirectory = Action('ConnectDirectory')
CreateAccount = Action('CreateAccount')
CreateApiKey = Action('CreateApiKey')
CreateBot = Action('CreateBot')
CreateBotMembership = Action('CreateBotMembership')
CreateCDRBucket = Action('CreateCDRBucket')
CreatePhoneNumberOrder = Action('CreatePhoneNumberOrder')
CreateVoiceConnector = Action('CreateVoiceConnector')
CreateVoiceConnectorGroup = Action('CreateVoiceConnectorGroup')
DeleteAccount = Action('DeleteAccount')
DeleteAccountOpenIdConfig = Action('DeleteAccountOpenIdConfig')
DeleteApiKey = Action('DeleteApiKey')
DeleteCDRBucket = Action('DeleteCDRBucket')
DeleteDelegate = Action('DeleteDelegate')
DeleteDomain = Action('DeleteDomain')
DeleteEventsConfiguration = Action('DeleteEventsConfiguration')
DeleteGroups = Action('DeleteGroups')
DeletePhoneNumber = Action('DeletePhoneNumber')
DeleteVoiceConnector = Action('DeleteVoiceConnector')
DeleteVoiceConnectorGroup = Action('DeleteVoiceConnectorGroup')
DeleteVoiceConnectorOrigination = \
    Action('DeleteVoiceConnectorOrigination')
DeleteVoiceConnectorStreamingConfiguration = \
    Action('DeleteVoiceConnectorStreamingConfiguration')
DeleteVoiceConnectorTermination = \
    Action('DeleteVoiceConnectorTermination')
DeleteVoiceConnectorTerminationCredentials = \
    Action('DeleteVoiceConnectorTerminationCredentials')
DisassociatePhoneNumberFromUser = \
    Action('DisassociatePhoneNumberFromUser')
DisassociatePhoneNumbersFromVoiceConnector = \
    Action('DisassociatePhoneNumbersFromVoiceConnector')
DisassociatePhoneNumbersFromVoiceConnectorGroup = \
    Action('DisassociatePhoneNumbersFromVoiceConnectorGroup')
DisconnectDirectory = Action('DisconnectDirectory')
GetAccount = Action('GetAccount')
GetAccountResource = Action('GetAccountResource')
GetAccountSettings = Action('GetAccountSettings')
GetAccountWithOpenIdConfig = Action('GetAccountWithOpenIdConfig')
GetBot = Action('GetBot')
GetCDRBucket = Action('GetCDRBucket')
GetDomain = Action('GetDomain')
GetEventsConfiguration = Action('GetEventsConfiguration')
GetGlobalSettings = Action('GetGlobalSettings')
GetMeetingDetail = Action('GetMeetingDetail')
GetPhoneNumber = Action('GetPhoneNumber')
GetPhoneNumberOrder = Action('GetPhoneNumberOrder')
GetPhoneNumberSettings = Action('GetPhoneNumberSettings')
GetTelephonyLimits = Action('GetTelephonyLimits')
GetUser = Action('GetUser')
GetUserActivityReportData = Action('GetUserActivityReportData')
GetUserByEmail = Action('GetUserByEmail')
GetUserSettings = Action('GetUserSettings')
GetVoiceConnector = Action('GetVoiceConnector')
GetVoiceConnectorGroup = Action('GetVoiceConnectorGroup')
GetVoiceConnectorLoggingConfiguration = \
    Action('GetVoiceConnectorLoggingConfiguration')
GetVoiceConnectorOrigination = Action('GetVoiceConnectorOrigination')
GetVoiceConnectorStreamingConfiguration = \
    Action('GetVoiceConnectorStreamingConfiguration')
GetVoiceConnectorTermination = Action('GetVoiceConnectorTermination')
GetVoiceConnectorTerminationHealth = \
    Action('GetVoiceConnectorTerminationHealth')
InviteDelegate = Action('InviteDelegate')
InviteUsers = Action('InviteUsers')
ListAccountUsageReportData = Action('ListAccountUsageReportData')
ListAccounts = Action('ListAccounts')
ListApiKeys = Action('ListApiKeys')
ListBots = Action('ListBots')
ListCDRBucket = Action('ListCDRBucket')
ListCallingRegions = Action('ListCallingRegions')
ListDelegates = Action('ListDelegates')
ListDirectories = Action('ListDirectories')
ListDomains = Action('ListDomains')
ListGroups = Action('ListGroups')
ListMeetingEvents = Action('ListMeetingEvents')
ListMeetingsReportData = Action('ListMeetingsReportData')
ListPhoneNumberOrders = Action('ListPhoneNumberOrders')
ListPhoneNumbers = Action('ListPhoneNumbers')
ListUsers = Action('ListUsers')
ListVoiceConnectorGroups = Action('ListVoiceConnectorGroups')
ListVoiceConnectorTerminationCredentials = \
    Action('ListVoiceConnectorTerminationCredentials')
ListVoiceConnectors = Action('ListVoiceConnectors')
LogoutUser = Action('LogoutUser')
PutEventsConfiguration = Action('PutEventsConfiguration')
PutVoiceConnectorLoggingConfiguration = \
    Action('PutVoiceConnectorLoggingConfiguration')
PutVoiceConnectorOrigination = Action('PutVoiceConnectorOrigination')
PutVoiceConnectorStreamingConfiguration = \
    Action('PutVoiceConnectorStreamingConfiguration')
PutVoiceConnectorTermination = Action('PutVoiceConnectorTermination')
PutVoiceConnectorTerminationCredentials = \
    Action('PutVoiceConnectorTerminationCredentials')
RegenerateSecurityToken = Action('RegenerateSecurityToken')
RenameAccount = Action('RenameAccount')
RenewDelegate = Action('RenewDelegate')
ResetAccountResource = Action('ResetAccountResource')
ResetPersonalPIN = Action('ResetPersonalPIN')
ResetPersonalPin = Action('ResetPersonalPin')
RestorePhoneNumber = Action('RestorePhoneNumber')
RetrieveDataExports = Action('RetrieveDataExports')
SearchAvailablePhoneNumbers = Action('SearchAvailablePhoneNumbers')
StartDataExport = Action('StartDataExport')
SubmitSupportRequest = Action('SubmitSupportRequest')
SuspendUsers = Action('SuspendUsers')
UnauthorizeDirectory = Action('UnauthorizeDirectory')
UpdateAccount = Action('UpdateAccount')
UpdateAccountOpenIdConfig = Action('UpdateAccountOpenIdConfig')
UpdateAccountResource = Action('UpdateAccountResource')
UpdateAccountSettings = Action('UpdateAccountSettings')
UpdateBot = Action('UpdateBot')
UpdateCDRBucket = Action('UpdateCDRBucket')
UpdateCDRSettings = Action('UpdateCDRSettings')
UpdateGlobalSettings = Action('UpdateGlobalSettings')
UpdatePhoneNumber = Action('UpdatePhoneNumber')
UpdatePhoneNumberSettings = Action('UpdatePhoneNumberSettings')
UpdateSupportedLicenses = Action('UpdateSupportedLicenses')
UpdateUser = Action('UpdateUser')
UpdateUserLicenses = Action('UpdateUserLicenses')
UpdateUserSettings = Action('UpdateUserSettings')
UpdateVoiceConnector = Action('UpdateVoiceConnector')
UpdateVoiceConnectorGroup = Action('UpdateVoiceConnectorGroup')
ValidateAccountResource = Action('ValidateAccountResource')
ValidateDelegate = Action('ValidateDelegate')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS RoboMaker'
prefix = 'robomaker'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchDescribeSimulationJob = Action('BatchDescribeSimulationJob')
CancelDeploymentJob = Action('CancelDeploymentJob')
CancelSimulationJob = Action('CancelSimulationJob')
CreateDeploymentJob = Action('CreateDeploymentJob')
CreateFleet = Action('CreateFleet')
CreateRobot = Action('CreateRobot')
CreateRobotApplication = Action('CreateRobotApplication')
CreateRobotApplicationVersion = Action('CreateRobotApplicationVersion')
CreateSimulationApplication = Action('CreateSimulationApplication')
CreateSimulationApplicationVersion = \
    Action('CreateSimulationApplicationVersion')
CreateSimulationJob = Action('CreateSimulationJob')
DeleteFleet = Action('DeleteFleet')
DeleteRobot = Action('DeleteRobot')
DeleteRobotApplication = Action('DeleteRobotApplication')
DeleteSimulationApplication = Action('DeleteSimulationApplication')
DeregisterRobot = Action('DeregisterRobot')
DescribeDeploymentJob = Action('DescribeDeploymentJob')
DescribeFleet = Action('DescribeFleet')
DescribeRobot = Action('DescribeRobot')
DescribeRobotApplication = Action('DescribeRobotApplication')
DescribeSimulationApplication = Action('DescribeSimulationApplication')
DescribeSimulationJob = Action('DescribeSimulationJob')
ListDeploymentJobs = Action('ListDeploymentJobs')
ListFleets = Action('ListFleets')
ListRobotApplications = Action('ListRobotApplications')
ListRobots = Action('ListRobots')
ListSimulationApplications = Action('ListSimulationApplications')
ListSimulationJobs = Action('ListSimulationJobs')
ListTagsForResource = Action('ListTagsForResource')
RegisterRobot = Action('RegisterRobot')
RestartSimulationJob = Action('RestartSimulationJob')
SyncDeploymentJob = Action('SyncDeploymentJob')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateRobotApplication = Action('UpdateRobotApplication')
UpdateSimulationApplication = Action('UpdateSimulationApplication')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Server Migration Service'
prefix = 'sms'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateApp = Action('CreateApp')
CreateReplicationJob = Action('CreateReplicationJob')
DeleteApp = Action('DeleteApp')
DeleteAppLaunchConfiguration = Action('DeleteAppLaunchConfiguration')
DeleteAppReplicationConfiguration = \
    Action('DeleteAppReplicationConfiguration')
DeleteReplicationJob = Action('DeleteReplicationJob')
DeleteServerCatalog = Action('DeleteServerCatalog')
DisassociateConnector = Action('DisassociateConnector')
DisassociateConnectors = Action('DisassociateConnectors')
GenerateChangeSet = Action('GenerateChangeSet')
GenerateTemplate = Action('GenerateTemplate')
GetApp = Action('GetApp')
GetAppLaunchConfiguration = Action('GetAppLaunchConfiguration')
GetAppReplicationConfiguration = Action('GetAppReplicationConfiguration')
GetConnectors = Action('GetConnectors')
GetMessages = Action('GetMessages')
GetReplicationJobs = Action('GetReplicationJobs')
GetReplicationRuns = Action('GetReplicationRuns')
GetServers = Action('GetServers')
ImportServerCatalog = Action('ImportServerCatalog')
LaunchApp = Action('LaunchApp')
ListApps = Action('ListApps')
PutAppLaunchConfiguration = Action('PutAppLaunchConfiguration')
PutAppReplicationConfiguration = Action('PutAppReplicationConfiguration')
SendMessage = Action('SendMessage')
StartAppReplication = Action('StartAppReplication')
StartOnDemandReplicationRun = Action('StartOnDemandReplicationRun')
StopAppReplication = Action('StopAppReplication')
TerminateApp = Action('TerminateApp')
UpdateApp = Action('UpdateApp')
UpdateReplicationJob = Action('UpdateReplicationJob')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Config'
prefix = 'config'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchGetAggregateResourceConfig = \
    Action('BatchGetAggregateResourceConfig')
BatchGetResourceConfig = Action('BatchGetResourceConfig')
DeleteAggregationAuthorization = Action('DeleteAggregationAuthorization')
DeleteConfigRule = Action('DeleteConfigRule')
DeleteConfigurationAggregator = Action('DeleteConfigurationAggregator')
DeleteConfigurationRecorder = Action('DeleteConfigurationRecorder')
DeleteDeliveryChannel = Action('DeleteDeliveryChannel')
DeleteEvaluationResults = Action('DeleteEvaluationResults')
DeletePendingAggregationRequest = \
    Action('DeletePendingAggregationRequest')
DeleteRemediationConfiguration = Action('DeleteRemediationConfiguration')
DeleteRetentionConfiguration = Action('DeleteRetentionConfiguration')
DeliverConfigSnapshot = Action('DeliverConfigSnapshot')
DescribeAggregateComplianceByConfigRules = \
    Action('DescribeAggregateComplianceByConfigRules')
DescribeAggregationAuthorizations = \
    Action('DescribeAggregationAuthorizations')
DescribeComplianceByConfigRule = Action('DescribeComplianceByConfigRule')
DescribeComplianceByResource = Action('DescribeComplianceByResource')
DescribeConfigRuleEvaluationStatus = \
    Action('DescribeConfigRuleEvaluationStatus')
DescribeConfigRules = Action('DescribeConfigRules')
DescribeConfigurationAggregatorSourcesStatus = \
    Action('DescribeConfigurationAggregatorSourcesStatus')
DescribeConfigurationAggregators = \
    Action('DescribeConfigurationAggregators')
DescribeConfigurationRecorderStatus = \
    Action('DescribeConfigurationRecorderStatus')
DescribeConfigurationRecorders = Action('DescribeConfigurationRecorders')
DescribeDeliveryChannelStatus = Action('DescribeDeliveryChannelStatus')
DescribeDeliveryChannels = Action('DescribeDeliveryChannels')
DescribePendingAggregationRequests = \
    Action('DescribePendingAggregationRequests')
DescribeRemediationConfigurations = \
    Action('DescribeRemediationConfigurations')
DescribeRemediationExecutionStatus = \
    Action('DescribeRemediationExecutionStatus')
DescribeRetentionConfigurations = \
    Action('DescribeRetentionConfigurations')
GetAggregateComplianceDetailsByConfigRule = \
    Action('GetAggregateComplianceDetailsByConfigRule')
GetAggregateConfigRuleComplianceSummary = \
    Action('GetAggregateConfigRuleComplianceSummary')
GetAggregateDiscoveredResourceCounts = \
    Action('GetAggregateDiscoveredResourceCounts')
GetAggregateResourceConfig = Action('GetAggregateResourceConfig')
GetComplianceDetailsByConfigRule = \
    Action('GetComplianceDetailsByConfigRule')
GetComplianceDetailsByResource = Action('GetComplianceDetailsByResource')
GetComplianceSummaryByConfigRule = \
    Action('GetComplianceSummaryByConfigRule')
GetComplianceSummaryByResourceType = \
    Action('GetComplianceSummaryByResourceType')
GetDiscoveredResourceCounts = Action('GetDiscoveredResourceCounts')
GetResourceConfigHistory = Action('GetResourceConfigHistory')
GetResources = Action('GetResources')
GetTagKeys = Action('GetTagKeys')
ListAggregateDiscoveredResources = \
    Action('ListAggregateDiscoveredResources')
ListDiscoveredResources = Action('ListDiscoveredResources')
ListTagsForResource = Action('ListTagsForResource')
PutAggregationAuthorization = Action('PutAggregationAuthorization')
PutConfigRule = Action('PutConfigRule')
PutConfigurationAggregator = Action('PutConfigurationAggregator')
PutConfigurationRecorder = Action('PutConfigurationRecorder')
PutDeliveryChannel = Action('PutDeliveryChannel')
PutEvaluations = Action('PutEvaluations')
PutRemediationConfigurations = Action('PutRemediationConfigurations')
PutRetentionConfiguration = Action('PutRetentionConfiguration')
SelectResourceConfig = Action('SelectResourceConfig')
StartConfigRulesEvaluation = Action('StartConfigRulesEvaluation')
StartConfigurationRecorder = Action('StartConfigurationRecorder')
StartRemediationExecution = Action('StartRemediationExecution')
StopConfigurationRecorder = Action('StopConfigurationRecorder')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon AppStream'
prefix = 'appstream'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateFleet = Action('AssociateFleet')
BatchAssociateUserStack = Action('BatchAssociateUserStack')
BatchDisassociateUserStack = Action('BatchDisassociateUserStack')
CopyImage = Action('CopyImage')
CreateDirectoryConfig = Action('CreateDirectoryConfig')
CreateFleet = Action('CreateFleet')
CreateImageBuilder = Action('CreateImageBuilder')
CreateImageBuilderStreamingURL = Action('CreateImageBuilderStreamingURL')
CreateStack = Action('CreateStack')
CreateStreamingURL = Action('CreateStreamingURL')
CreateUsageReportSubscription = Action('CreateUsageReportSubscription')
CreateUser = Action('CreateUser')
DeleteDirectoryConfig = Action('DeleteDirectoryConfig')
DeleteFleet = Action('DeleteFleet')
DeleteImage = Action('DeleteImage')
DeleteImageBuilder = Action('DeleteImageBuilder')
DeleteImagePermissions = Action('DeleteImagePermissions')
DeleteStack = Action('DeleteStack')
DeleteUsageReportSubscription = Action('DeleteUsageReportSubscription')
DeleteUser = Action('DeleteUser')
DescribeDirectoryConfigs = Action('DescribeDirectoryConfigs')
DescribeFleets = Action('DescribeFleets')
DescribeImageBuilders = Action('DescribeImageBuilders')
DescribeImagePermissions = Action('DescribeImagePermissions')
DescribeImages = Action('DescribeImages')
DescribeSessions = Action('DescribeSessions')
DescribeStacks = Action('DescribeStacks')
DescribeUsageReportSubscriptions = \
    Action('DescribeUsageReportSubscriptions')
DescribeUserStackAssociations = Action('DescribeUserStackAssociations')
DescribeUsers = Action('DescribeUsers')
DisableUser = Action('DisableUser')
DisassociateFleet = Action('DisassociateFleet')
EnableUser = Action('EnableUser')
ExpireSession = Action('ExpireSession')
GetImageBuilders = Action('GetImageBuilders')
GetParametersForThemeAssetUpload = \
    Action('GetParametersForThemeAssetUpload')
ListAssociatedFleets = Action('ListAssociatedFleets')
ListAssociatedStacks = Action('ListAssociatedStacks')
ListTagsForResource = Action('ListTagsForResource')
StartFleet = Action('StartFleet')
StartImageBuilder = Action('StartImageBuilder')
StopFleet = Action('StopFleet')
StopImageBuilder = Action('StopImageBuilder')
Stream = Action('Stream')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateDirectoryConfig = Action('UpdateDirectoryConfig')
UpdateFleet = Action('UpdateFleet')
UpdateImagePermissions = Action('UpdateImagePermissions')
UpdateStack = Action('UpdateStack')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Cloud9'
prefix = 'cloud9'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateEnvironmentEC2 = Action('CreateEnvironmentEC2')
CreateEnvironmentMembership = Action('CreateEnvironmentMembership')
CreateEnvironmentSSH = Action('CreateEnvironmentSSH')
DeleteEnvironment = Action('DeleteEnvironment')
DeleteEnvironmentMembership = Action('DeleteEnvironmentMembership')
DescribeEnvironmentMemberships = Action('DescribeEnvironmentMemberships')
DescribeEnvironmentStatus = Action('DescribeEnvironmentStatus')
DescribeEnvironments = Action('DescribeEnvironments')
GetUserPublicKey = Action('GetUserPublicKey')
ListEnvironments = Action('ListEnvironments')
UpdateEnvironment = Action('UpdateEnvironment')
UpdateEnvironmentMembership = Action('UpdateEnvironmentMembership')
ValidateEnvironmentName = Action('ValidateEnvironmentName')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Kinesis'
prefix = 'kinesis'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddTagsToStream = Action('AddTagsToStream')
CreateStream = Action('CreateStream')
DecreaseStreamRetentionPeriod = Action('DecreaseStreamRetentionPeriod')
DeleteStream = Action('DeleteStream')
DeregisterStreamConsumer = Action('DeregisterStreamConsumer')
DescribeLimits = Action('DescribeLimits')
DescribeStream = Action('DescribeStream')
DescribeStreamConsumer = Action('DescribeStreamConsumer')
DescribeStreamSummary = Action('DescribeStreamSummary')
DisableEnhancedMonitoring = Action('DisableEnhancedMonitoring')
EnableEnhancedMonitoring = Action('EnableEnhancedMonitoring')
GetRecords = Action('GetRecords')
GetShardIterator = Action('GetShardIterator')
IncreaseStreamRetentionPeriod = Action('IncreaseStreamRetentionPeriod')
ListShards = Action('ListShards')
ListStreamConsumers = Action('ListStreamConsumers')
ListStreams = Action('ListStreams')
ListTagsForStream = Action('ListTagsForStream')
MergeShards = Action('MergeShards')
PutRecord = Action('PutRecord')
PutRecords = Action('PutRecords')
RegisterStreamConsumer = Action('RegisterStreamConsumer')
RemoveTagsFromStream = Action('RemoveTagsFromStream')
SplitShard = Action('SplitShard')
StartStreamEncryption = Action('StartStreamEncryption')
StopStreamEncryption = Action('StopStreamEncryption')
SubscribeToShard = Action('SubscribeToShard')
UpdateShardCount = Action('UpdateShardCount')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon GuardDuty'
prefix = 'guardduty'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptInvitation = Action('AcceptInvitation')
ArchiveFindings = Action('ArchiveFindings')
CreateDetector = Action('CreateDetector')
CreateFilter = Action('CreateFilter')
CreateIPSet = Action('CreateIPSet')
CreateMembers = Action('CreateMembers')
CreateSampleFindings = Action('CreateSampleFindings')
CreateThreatIntelSet = Action('CreateThreatIntelSet')
DeclineInvitations = Action('DeclineInvitations')
DeleteDetector = Action('DeleteDetector')
DeleteFilter = Action('DeleteFilter')
DeleteIPSet = Action('DeleteIPSet')
DeleteInvitations = Action('DeleteInvitations')
DeleteMembers = Action('DeleteMembers')
DeleteThreatIntelSet = Action('DeleteThreatIntelSet')
DisassociateFromMasterAccount = Action('DisassociateFromMasterAccount')
DisassociateMembers = Action('DisassociateMembers')
GetDetector = Action('GetDetector')
GetFilter = Action('GetFilter')
GetFindings = Action('GetFindings')
GetFindingsStatistics = Action('GetFindingsStatistics')
GetIPSet = Action('GetIPSet')
GetInvitationsCount = Action('GetInvitationsCount')
GetMasterAccount = Action('GetMasterAccount')
GetMembers = Action('GetMembers')
GetThreatIntelSet = Action('GetThreatIntelSet')
InviteMembers = Action('InviteMembers')
ListDetectors = Action('ListDetectors')
ListFilters = Action('ListFilters')
ListFindings = Action('ListFindings')
ListIPSets = Action('ListIPSets')
ListInvitations = Action('ListInvitations')
ListMembers = Action('ListMembers')
ListTagsForResource = Action('ListTagsForResource')
ListThreatIntelSets = Action('ListThreatIntelSets')
StartMonitoringMembers = Action('StartMonitoringMembers')
StopMonitoringMembers = Action('StopMonitoringMembers')
TagResource = Action('TagResource')
UnarchiveFindings = Action('UnarchiveFindings')
UntagResource = Action('UntagResource')
UpdateDetector = Action('UpdateDetector')
UpdateFilter = Action('UpdateFilter')
UpdateFindingsFeedback = Action('UpdateFindingsFeedback')
UpdateIPSet = Action('UpdateIPSet')
UpdateThreatIntelSet = Action('UpdateThreatIntelSet')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Route 53'
prefix = 'route53'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateVPCWithHostedZone = Action('AssociateVPCWithHostedZone')
ChangeResourceRecordSets = Action('ChangeResourceRecordSets')
ChangeTagsForResource = Action('ChangeTagsForResource')
CreateHealthCheck = Action('CreateHealthCheck')
CreateHostedZone = Action('CreateHostedZone')
CreateQueryLoggingConfig = Action('CreateQueryLoggingConfig')
CreateReusableDelegationSet = Action('CreateReusableDelegationSet')
CreateTrafficPolicy = Action('CreateTrafficPolicy')
CreateTrafficPolicyInstance = Action('CreateTrafficPolicyInstance')
CreateTrafficPolicyVersion = Action('CreateTrafficPolicyVersion')
CreateVPCAssociationAuthorization = \
    Action('CreateVPCAssociationAuthorization')
DeleteHealthCheck = Action('DeleteHealthCheck')
DeleteHostedZone = Action('DeleteHostedZone')
DeleteQueryLoggingConfig = Action('DeleteQueryLoggingConfig')
DeleteReusableDelegationSet = Action('DeleteReusableDelegationSet')
DeleteTrafficPolicy = Action('DeleteTrafficPolicy')
DeleteTrafficPolicyInstance = Action('DeleteTrafficPolicyInstance')
DeleteVPCAssociationAuthorization = \
    Action('DeleteVPCAssociationAuthorization')
DisableDomainAutoRenew = Action('DisableDomainAutoRenew')
DisassociateVPCFromHostedZone = Action('DisassociateVPCFromHostedZone')
EnableDomainAutoRenew = Action('EnableDomainAutoRenew')
GetAccountLimit = Action('GetAccountLimit')
GetChange = Action('GetChange')
GetCheckerIpRanges = Action('GetCheckerIpRanges')
GetGeoLocation = Action('GetGeoLocation')
GetHealthCheck = Action('GetHealthCheck')
GetHealthCheckCount = Action('GetHealthCheckCount')
GetHealthCheckLastFailureReason = \
    Action('GetHealthCheckLastFailureReason')
GetHealthCheckStatus = Action('GetHealthCheckStatus')
GetHostedZone = Action('GetHostedZone')
GetHostedZoneCount = Action('GetHostedZoneCount')
GetHostedZoneLimit = Action('GetHostedZoneLimit')
GetQueryLoggingConfig = Action('GetQueryLoggingConfig')
GetReusableDelegationSet = Action('GetReusableDelegationSet')
GetReusableDelegationSetLimit = Action('GetReusableDelegationSetLimit')
GetTrafficPolicy = Action('GetTrafficPolicy')
GetTrafficPolicyInstance = Action('GetTrafficPolicyInstance')
GetTrafficPolicyInstanceCount = Action('GetTrafficPolicyInstanceCount')
ListGeoLocations = Action('ListGeoLocations')
ListHealthChecks = Action('ListHealthChecks')
ListHostedZones = Action('ListHostedZones')
ListHostedZonesByName = Action('ListHostedZonesByName')
ListQueryLoggingConfigs = Action('ListQueryLoggingConfigs')
ListResourceRecordSets = Action('ListResourceRecordSets')
ListReusableDelegationSets = Action('ListReusableDelegationSets')
ListTagsForResource = Action('ListTagsForResource')
ListTagsForResources = Action('ListTagsForResources')
ListTrafficPolicies = Action('ListTrafficPolicies')
ListTrafficPolicyInstances = Action('ListTrafficPolicyInstances')
ListTrafficPolicyInstancesByHostedZone = \
    Action('ListTrafficPolicyInstancesByHostedZone')
ListTrafficPolicyInstancesByPolicy = \
    Action('ListTrafficPolicyInstancesByPolicy')
ListTrafficPolicyVersions = Action('ListTrafficPolicyVersions')
ListVPCAssociationAuthorizations = \
    Action('ListVPCAssociationAuthorizations')
TestDNSAnswer = Action('TestDNSAnswer')
UpdateHealthCheck = Action('UpdateHealthCheck')
UpdateHostedZoneComment = Action('UpdateHostedZoneComment')
UpdateTrafficPolicyComment = Action('UpdateTrafficPolicyComment')
UpdateTrafficPolicyInstance = Action('UpdateTrafficPolicyInstance')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon RDS'
prefix = 'rds'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddRoleToDBCluster = Action('AddRoleToDBCluster')
AddRoleToDBInstance = Action('AddRoleToDBInstance')
AddSourceIdentifierToSubscription = \
    Action('AddSourceIdentifierToSubscription')
AddTagsToResource = Action('AddTagsToResource')
ApplyPendingMaintenanceAction = Action('ApplyPendingMaintenanceAction')
AuthorizeDBSecurityGroupIngress = \
    Action('AuthorizeDBSecurityGroupIngress')
BacktrackDBCluster = Action('BacktrackDBCluster')
CopyDBClusterParameterGroup = Action('CopyDBClusterParameterGroup')
CopyDBClusterSnapshot = Action('CopyDBClusterSnapshot')
CopyDBParameterGroup = Action('CopyDBParameterGroup')
CopyDBSnapshot = Action('CopyDBSnapshot')
CopyOptionGroup = Action('CopyOptionGroup')
CreateDBCluster = Action('CreateDBCluster')
CreateDBClusterEndpoint = Action('CreateDBClusterEndpoint')
CreateDBClusterParameterGroup = Action('CreateDBClusterParameterGroup')
CreateDBClusterSnapshot = Action('CreateDBClusterSnapshot')
CreateDBInstance = Action('CreateDBInstance')
CreateDBInstanceReadReplica = Action('CreateDBInstanceReadReplica')
CreateDBParameterGroup = Action('CreateDBParameterGroup')
CreateDBSecurityGroup = Action('CreateDBSecurityGroup')
CreateDBSnapshot = Action('CreateDBSnapshot')
CreateDBSubnetGroup = Action('CreateDBSubnetGroup')
CreateEventSubscription = Action('CreateEventSubscription')
CreateGlobalCluster = Action('CreateGlobalCluster')
CreateOptionGroup = Action('CreateOptionGroup')
DeleteDBCluster = Action('DeleteDBCluster')
DeleteDBClusterEndpoint = Action('DeleteDBClusterEndpoint')
DeleteDBClusterParameterGroup = Action('DeleteDBClusterParameterGroup')
DeleteDBClusterSnapshot = Action('DeleteDBClusterSnapshot')
DeleteDBInstance = Action('DeleteDBInstance')
DeleteDBInstanceAutomatedBackup = \
    Action('DeleteDBInstanceAutomatedBackup')
DeleteDBParameterGroup = Action('DeleteDBParameterGroup')
DeleteDBSecurityGroup = Action('DeleteDBSecurityGroup')
DeleteDBSnapshot = Action('DeleteDBSnapshot')
DeleteDBSubnetGroup = Action('DeleteDBSubnetGroup')
DeleteEventSubscription = Action('DeleteEventSubscription')
DeleteGlobalCluster = Action('DeleteGlobalCluster')
DeleteOptionGroup = Action('DeleteOptionGroup')
DescribeAccountAttributes = Action('DescribeAccountAttributes')
DescribeCertificates = Action('DescribeCertificates')
DescribeDBClusterBacktracks = Action('DescribeDBClusterBacktracks')
DescribeDBClusterEndpoints = Action('DescribeDBClusterEndpoints')
DescribeDBClusterParameterGroups = \
    Action('DescribeDBClusterParameterGroups')
DescribeDBClusterParameters = Action('DescribeDBClusterParameters')
DescribeDBClusterSnapshotAttributes = \
    Action('DescribeDBClusterSnapshotAttributes')
DescribeDBClusterSnapshots = Action('DescribeDBClusterSnapshots')
DescribeDBClusters = Action('DescribeDBClusters')
DescribeDBEngineVersions = Action('DescribeDBEngineVersions')
DescribeDBInstanceAutomatedBackups = \
    Action('DescribeDBInstanceAutomatedBackups')
DescribeDBInstances = Action('DescribeDBInstances')
DescribeDBLogFiles = Action('DescribeDBLogFiles')
DescribeDBParameterGroups = Action('DescribeDBParameterGroups')
DescribeDBParameters = Action('DescribeDBParameters')
DescribeDBSecurityGroups = Action('DescribeDBSecurityGroups')
DescribeDBSnapshotAttributes = Action('DescribeDBSnapshotAttributes')
DescribeDBSnapshots = Action('DescribeDBSnapshots')
DescribeDBSubnetGroups = Action('DescribeDBSubnetGroups')
DescribeEngineDefaultClusterParameters = \
    Action('DescribeEngineDefaultClusterParameters')
DescribeEngineDefaultParameters = \
    Action('DescribeEngineDefaultParameters')
DescribeEventCategories = Action('DescribeEventCategories')
DescribeEventSubscriptions = Action('DescribeEventSubscriptions')
DescribeEvents = Action('DescribeEvents')
DescribeGlobalClusters = Action('DescribeGlobalClusters')
DescribeOptionGroupOptions = Action('DescribeOptionGroupOptions')
DescribeOptionGroups = Action('DescribeOptionGroups')
DescribeOrderableDBInstanceOptions = \
    Action('DescribeOrderableDBInstanceOptions')
DescribePendingMaintenanceActions = \
    Action('DescribePendingMaintenanceActions')
DescribeReservedDBInstances = Action('DescribeReservedDBInstances')
DescribeReservedDBInstancesOfferings = \
    Action('DescribeReservedDBInstancesOfferings')
DescribeSourceRegions = Action('DescribeSourceRegions')
DescribeValidDBInstanceModifications = \
    Action('DescribeValidDBInstanceModifications')
DownloadCompleteDBLogFile = Action('DownloadCompleteDBLogFile')
DownloadDBLogFilePortion = Action('DownloadDBLogFilePortion')
FailoverDBCluster = Action('FailoverDBCluster')
ListTagsForResource = Action('ListTagsForResource')
ModifyCurrentDBClusterCapacity = Action('ModifyCurrentDBClusterCapacity')
ModifyDBCluster = Action('ModifyDBCluster')
ModifyDBClusterEndpoint = Action('ModifyDBClusterEndpoint')
ModifyDBClusterParameterGroup = Action('ModifyDBClusterParameterGroup')
ModifyDBClusterSnapshotAttribute = \
    Action('ModifyDBClusterSnapshotAttribute')
ModifyDBInstance = Action('ModifyDBInstance')
ModifyDBParameterGroup = Action('ModifyDBParameterGroup')
ModifyDBSnapshot = Action('ModifyDBSnapshot')
ModifyDBSnapshotAttribute = Action('ModifyDBSnapshotAttribute')
ModifyDBSubnetGroup = Action('ModifyDBSubnetGroup')
ModifyEventSubscription = Action('ModifyEventSubscription')
ModifyGlobalCluster = Action('ModifyGlobalCluster')
ModifyOptionGroup = Action('ModifyOptionGroup')
PromoteReadReplica = Action('PromoteReadReplica')
PromoteReadReplicaDBCluster = Action('PromoteReadReplicaDBCluster')
PurchaseReservedDBInstancesOffering = \
    Action('PurchaseReservedDBInstancesOffering')
RebootDBInstance = Action('RebootDBInstance')
RemoveFromGlobalCluster = Action('RemoveFromGlobalCluster')
RemoveRoleFromDBCluster = Action('RemoveRoleFromDBCluster')
RemoveRoleFromDBInstance = Action('RemoveRoleFromDBInstance')
RemoveSourceIdentifierFromSubscription = \
    Action('RemoveSourceIdentifierFromSubscription')
RemoveTagsFromResource = Action('RemoveTagsFromResource')
ResetDBClusterParameterGroup = Action('ResetDBClusterParameterGroup')
ResetDBParameterGroup = Action('ResetDBParameterGroup')
RestoreDBClusterFromS3 = Action('RestoreDBClusterFromS3')
RestoreDBClusterFromSnapshot = Action('RestoreDBClusterFromSnapshot')
RestoreDBClusterToPointInTime = Action('RestoreDBClusterToPointInTime')
RestoreDBInstanceFromDBSnapshot = \
    Action('RestoreDBInstanceFromDBSnapshot')
RestoreDBInstanceFromS3 = Action('RestoreDBInstanceFromS3')
RestoreDBInstanceToPointInTime = Action('RestoreDBInstanceToPointInTime')
RevokeDBSecurityGroupIngress = Action('RevokeDBSecurityGroupIngress')
StartActivityStream = Action('StartActivityStream')
StartDBCluster = Action('StartDBCluster')
StartDBInstance = Action('StartDBInstance')
StopActivityStream = Action('StopActivityStream')
StopDBCluster = Action('StopDBCluster')
StopDBInstance = Action('StopDBInstance')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon FreeRTOS'
prefix = 'freertos'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateSoftwareConfiguration = Action('CreateSoftwareConfiguration')
DeleteSoftwareConfiguration = Action('DeleteSoftwareConfiguration')
DescribeHardwarePlatform = Action('DescribeHardwarePlatform')
DescribeSoftwareConfiguration = Action('DescribeSoftwareConfiguration')
GetSoftwareURL = Action('GetSoftwareURL')
GetSoftwareURLForConfiguration = Action('GetSoftwareURLForConfiguration')
ListFreeRTOSVersions = Action('ListFreeRTOSVersions')
ListHardwarePlatforms = Action('ListHardwarePlatforms')
ListHardwareVendors = Action('ListHardwareVendors')
ListSoftwareConfigurations = Action('ListSoftwareConfigurations')
UpdateSoftwareConfiguration = Action('UpdateSoftwareConfiguration')



import os
import re
import sys
import unittest

from functools import partial


class TestExamples(unittest.TestCase):
    pass


def test_file(filename):
    # Ignore the output
    saved = sys.stdout
    with open('/dev/null', 'w') as stdout:
        sys.stdout = stdout
        try:
            with open(filename) as f:
                code = compile(f.read(), filename, 'exec')
                exec(code)
        finally:
            sys.stdout = saved


def add_tests():
    # Filter out all *.py files from the examples directory
    examples = 'examples'
    regex = re.compile(r'.py$', re.I)
    example_filesnames = filter(regex.search, os.listdir(examples))

    # Add new test functions to the TestExamples class
    for f in example_filesnames:
        testname = 'test_' + f[:-3]
        testfunc = partial(test_file, examples + '/' + f)
        # Get rid of partial() __doc__
        testfunc.__doc__ = None
        setattr(TestExamples, testname, testfunc)


add_tests()

if __name__ == '__main__':
    unittest.main()



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Security Hub'
prefix = 'securityhub'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptInvitation = Action('AcceptInvitation')
BatchDisableStandards = Action('BatchDisableStandards')
BatchEnableStandards = Action('BatchEnableStandards')
BatchImportFindings = Action('BatchImportFindings')
CreateActionTarget = Action('CreateActionTarget')
CreateInsight = Action('CreateInsight')
CreateMembers = Action('CreateMembers')
DeclineInvitations = Action('DeclineInvitations')
DeleteActionTarget = Action('DeleteActionTarget')
DeleteInsight = Action('DeleteInsight')
DeleteInvitations = Action('DeleteInvitations')
DeleteMembers = Action('DeleteMembers')
DescribeActionTargets = Action('DescribeActionTargets')
DescribeHub = Action('DescribeHub')
DescribeProducts = Action('DescribeProducts')
DisableImportFindingsForProduct = \
    Action('DisableImportFindingsForProduct')
DisableSecurityHub = Action('DisableSecurityHub')
DisassociateFromMasterAccount = Action('DisassociateFromMasterAccount')
DisassociateMembers = Action('DisassociateMembers')
EnableImportFindingsForProduct = Action('EnableImportFindingsForProduct')
EnableSecurityHub = Action('EnableSecurityHub')
GetEnabledStandards = Action('GetEnabledStandards')
GetFindings = Action('GetFindings')
GetInsightResults = Action('GetInsightResults')
GetInsights = Action('GetInsights')
GetInvitationsCount = Action('GetInvitationsCount')
GetMasterAccount = Action('GetMasterAccount')
GetMembers = Action('GetMembers')
InviteMembers = Action('InviteMembers')
ListEnabledProductsForImport = Action('ListEnabledProductsForImport')
ListInvitations = Action('ListInvitations')
ListMembers = Action('ListMembers')
ListProductSubscribers = Action('ListProductSubscribers')
ListTagsForResource = Action('ListTagsForResource')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateActionTarget = Action('UpdateActionTarget')
UpdateFindings = Action('UpdateFindings')
UpdateInsight = Action('UpdateInsight')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Macie'
prefix = 'macie'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateMemberAccount = Action('AssociateMemberAccount')
AssociateS3Resources = Action('AssociateS3Resources')
DisassociateMemberAccount = Action('DisassociateMemberAccount')
DisassociateS3Resources = Action('DisassociateS3Resources')
ListMemberAccounts = Action('ListMemberAccounts')
ListS3Resources = Action('ListS3Resources')
UpdateS3Resources = Action('UpdateS3Resources')



import unittest

import awacs.aws as aws
import awacs.s3 as s3
import json


class TestConditions(unittest.TestCase):
    def test_for_all_values(self):
        c = aws.Condition(aws.ForAllValuesStringLike(
            "dynamodb:requestedAttributes", [
                "PostDateTime",
                "Message",
                "Tags"
            ]))
        pd = aws.PolicyDocument(
            Statement=[
                aws.Statement(
                    Action=[s3.ListBucket],
                    Effect=aws.Allow,
                    Resource=[s3.ARN("myBucket")],
                    Condition=c,
                )])
        self.assertEqual({u'Statement': [
            {
                u'Action': [u's3:ListBucket'],
                u'Condition': {u'ForAllValues:StringLike':
                               {u'dynamodb:requestedAttributes':
                                [u'PostDateTime', u'Message', u'Tags']}},
                u'Effect': u'Allow',
                u'Resource': [u'arn:aws:s3:::myBucket']}
            ]},
            json.loads(pd.to_json()))



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Global Accelerator'
prefix = 'globalaccelerator'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateAccelerator = Action('CreateAccelerator')
CreateEndpointGroup = Action('CreateEndpointGroup')
CreateListener = Action('CreateListener')
DeleteAccelerator = Action('DeleteAccelerator')
DeleteEndpointGroup = Action('DeleteEndpointGroup')
DeleteListener = Action('DeleteListener')
DescribeAccelerator = Action('DescribeAccelerator')
DescribeAcceleratorAttributes = Action('DescribeAcceleratorAttributes')
DescribeEndpointGroup = Action('DescribeEndpointGroup')
DescribeListener = Action('DescribeListener')
ListAccelerators = Action('ListAccelerators')
ListEndpointGroups = Action('ListEndpointGroups')
ListListeners = Action('ListListeners')
UpdateAccelerator = Action('UpdateAccelerator')
UpdateAcceleratorAttributes = Action('UpdateAcceleratorAttributes')
UpdateEndpointGroup = Action('UpdateEndpointGroup')
UpdateListener = Action('UpdateListener')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon CloudWatch Logs'
prefix = 'logs'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateKmsKey = Action('AssociateKmsKey')
CancelExportTask = Action('CancelExportTask')
CreateExportTask = Action('CreateExportTask')
CreateLogDelivery = Action('CreateLogDelivery')
CreateLogGroup = Action('CreateLogGroup')
CreateLogStream = Action('CreateLogStream')
DeleteDestination = Action('DeleteDestination')
DeleteLogDelivery = Action('DeleteLogDelivery')
DeleteLogGroup = Action('DeleteLogGroup')
DeleteLogStream = Action('DeleteLogStream')
DeleteMetricFilter = Action('DeleteMetricFilter')
DeleteResourcePolicy = Action('DeleteResourcePolicy')
DeleteRetentionPolicy = Action('DeleteRetentionPolicy')
DeleteSubscriptionFilter = Action('DeleteSubscriptionFilter')
DescribeDestinations = Action('DescribeDestinations')
DescribeExportTasks = Action('DescribeExportTasks')
DescribeLogGroups = Action('DescribeLogGroups')
DescribeLogStreams = Action('DescribeLogStreams')
DescribeMetricFilters = Action('DescribeMetricFilters')
DescribeQueries = Action('DescribeQueries')
DescribeResourcePolicies = Action('DescribeResourcePolicies')
DescribeSubscriptionFilters = Action('DescribeSubscriptionFilters')
DisassociateKmsKey = Action('DisassociateKmsKey')
FilterLogEvents = Action('FilterLogEvents')
GetLogDelivery = Action('GetLogDelivery')
GetLogEvents = Action('GetLogEvents')
GetLogGroupFields = Action('GetLogGroupFields')
GetLogRecord = Action('GetLogRecord')
GetQueryResults = Action('GetQueryResults')
ListLogDeliveries = Action('ListLogDeliveries')
ListTagsLogGroup = Action('ListTagsLogGroup')
PutDestination = Action('PutDestination')
PutDestinationPolicy = Action('PutDestinationPolicy')
PutLogEvents = Action('PutLogEvents')
PutMetricFilter = Action('PutMetricFilter')
PutResourcePolicy = Action('PutResourcePolicy')
PutRetentionPolicy = Action('PutRetentionPolicy')
PutSubscriptionFilter = Action('PutSubscriptionFilter')
StartQuery = Action('StartQuery')
StopQuery = Action('StopQuery')
TagLogGroup = Action('TagLogGroup')
TestMetricFilter = Action('TestMetricFilter')
UntagLogGroup = Action('UntagLogGroup')
UpdateLogDelivery = Action('UpdateLogDelivery')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon WorkMail'
prefix = 'workmail'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddMembersToGroup = Action('AddMembersToGroup')
AssociateDelegateToResource = Action('AssociateDelegateToResource')
AssociateMemberToGroup = Action('AssociateMemberToGroup')
CreateAlias = Action('CreateAlias')
CreateGroup = Action('CreateGroup')
CreateInboundMailFlowRule = Action('CreateInboundMailFlowRule')
CreateMailDomain = Action('CreateMailDomain')
CreateMailUser = Action('CreateMailUser')
CreateOrganization = Action('CreateOrganization')
CreateOutboundMailFlowRule = Action('CreateOutboundMailFlowRule')
CreateResource = Action('CreateResource')
CreateSmtpGateway = Action('CreateSmtpGateway')
CreateUser = Action('CreateUser')
DeleteAlias = Action('DeleteAlias')
DeleteGroup = Action('DeleteGroup')
DeleteInboundMailFlowRule = Action('DeleteInboundMailFlowRule')
DeleteMailDomain = Action('DeleteMailDomain')
DeleteMailboxPermissions = Action('DeleteMailboxPermissions')
DeleteMobileDevice = Action('DeleteMobileDevice')
DeleteOrganization = Action('DeleteOrganization')
DeleteOutboundMailFlowRule = Action('DeleteOutboundMailFlowRule')
DeleteResource = Action('DeleteResource')
DeleteSmtpGateway = Action('DeleteSmtpGateway')
DeleteUser = Action('DeleteUser')
DeregisterFromWorkMail = Action('DeregisterFromWorkMail')
DescribeDirectories = Action('DescribeDirectories')
DescribeGroup = Action('DescribeGroup')
DescribeInboundMailFlowRule = Action('DescribeInboundMailFlowRule')
DescribeKmsKeys = Action('DescribeKmsKeys')
DescribeMailDomains = Action('DescribeMailDomains')
DescribeMailGroups = Action('DescribeMailGroups')
DescribeMailUsers = Action('DescribeMailUsers')
DescribeOrganization = Action('DescribeOrganization')
DescribeOrganizations = Action('DescribeOrganizations')
DescribeOutboundMailFlowRule = Action('DescribeOutboundMailFlowRule')
DescribeResource = Action('DescribeResource')
DescribeSmtpGateway = Action('DescribeSmtpGateway')
DescribeUser = Action('DescribeUser')
DisableMailGroups = Action('DisableMailGroups')
DisableMailUsers = Action('DisableMailUsers')
DisassociateDelegateFromResource = \
    Action('DisassociateDelegateFromResource')
DisassociateMemberFromGroup = Action('DisassociateMemberFromGroup')
EnableMailDomain = Action('EnableMailDomain')
EnableMailGroups = Action('EnableMailGroups')
EnableMailUsers = Action('EnableMailUsers')
GetJournalingRules = Action('GetJournalingRules')
GetMailDomainDetails = Action('GetMailDomainDetails')
GetMailGroupDetails = Action('GetMailGroupDetails')
GetMailUserDetails = Action('GetMailUserDetails')
GetMailboxDetails = Action('GetMailboxDetails')
GetMobileDeviceDetails = Action('GetMobileDeviceDetails')
GetMobileDevicesForUser = Action('GetMobileDevicesForUser')
GetMobilePolicyDetails = Action('GetMobilePolicyDetails')
ListAliases = Action('ListAliases')
ListGroupMembers = Action('ListGroupMembers')
ListGroups = Action('ListGroups')
ListInboundMailFlowRules = Action('ListInboundMailFlowRules')
ListMailboxPermissions = Action('ListMailboxPermissions')
ListMembersInMailGroup = Action('ListMembersInMailGroup')
ListOrganizations = Action('ListOrganizations')
ListOutboundMailFlowRules = Action('ListOutboundMailFlowRules')
ListResourceDelegates = Action('ListResourceDelegates')
ListResources = Action('ListResources')
ListSmtpGateways = Action('ListSmtpGateways')
ListUsers = Action('ListUsers')
PutMailboxPermissions = Action('PutMailboxPermissions')
RegisterToWorkMail = Action('RegisterToWorkMail')
RemoveMembersFromGroup = Action('RemoveMembersFromGroup')
ResetPassword = Action('ResetPassword')
ResetUserPassword = Action('ResetUserPassword')
SearchMembers = Action('SearchMembers')
SetAdmin = Action('SetAdmin')
SetDefaultMailDomain = Action('SetDefaultMailDomain')
SetJournalingRules = Action('SetJournalingRules')
SetMailGroupDetails = Action('SetMailGroupDetails')
SetMailUserDetails = Action('SetMailUserDetails')
SetMobilePolicyDetails = Action('SetMobilePolicyDetails')
TestInboundMailFlowRules = Action('TestInboundMailFlowRules')
TestOutboundMailFlowRules = Action('TestOutboundMailFlowRules')
UpdateInboundMailFlowRule = Action('UpdateInboundMailFlowRule')
UpdateMailboxQuota = Action('UpdateMailboxQuota')
UpdateOutboundMailFlowRule = Action('UpdateOutboundMailFlowRule')
UpdatePrimaryEmailAddress = Action('UpdatePrimaryEmailAddress')
UpdateResource = Action('UpdateResource')
UpdateSmtpGateway = Action('UpdateSmtpGateway')
WipeMobileDevice = Action('WipeMobileDevice')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS IoT 1-Click'
prefix = 'iot1click'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateDeviceWithPlacement = Action('AssociateDeviceWithPlacement')
ClaimDevicesByClaimCode = Action('ClaimDevicesByClaimCode')
CreatePlacement = Action('CreatePlacement')
CreateProject = Action('CreateProject')
DeletePlacement = Action('DeletePlacement')
DeleteProject = Action('DeleteProject')
DescribeDevice = Action('DescribeDevice')
DescribePlacement = Action('DescribePlacement')
DescribeProject = Action('DescribeProject')
DisassociateDeviceFromPlacement = \
    Action('DisassociateDeviceFromPlacement')
FinalizeDeviceClaim = Action('FinalizeDeviceClaim')
GetDeviceMethods = Action('GetDeviceMethods')
GetDevicesInPlacement = Action('GetDevicesInPlacement')
InitializeDeviceClaim = Action('InitializeDeviceClaim')
InitiateDeviceClaim = Action('InitiateDeviceClaim')
InvokeDeviceMethod = Action('InvokeDeviceMethod')
ListDeviceEvents = Action('ListDeviceEvents')
ListDevices = Action('ListDevices')
ListPlacements = Action('ListPlacements')
ListProjects = Action('ListProjects')
ListTagsForResource = Action('ListTagsForResource')
TagResource = Action('TagResource')
UnclaimDevice = Action('UnclaimDevice')
UntagResource = Action('UntagResource')
UpdateDeviceState = Action('UpdateDeviceState')
UpdatePlacement = Action('UpdatePlacement')
UpdateProject = Action('UpdateProject')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon EC2'
prefix = 'ec2'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptReservedInstancesExchangeQuote = \
    Action('AcceptReservedInstancesExchangeQuote')
AcceptTransitGatewayVpcAttachment = \
    Action('AcceptTransitGatewayVpcAttachment')
AcceptVpcEndpointConnections = Action('AcceptVpcEndpointConnections')
AcceptVpcPeeringConnection = Action('AcceptVpcPeeringConnection')
AdvertiseByoipCidr = Action('AdvertiseByoipCidr')
AllocateAddress = Action('AllocateAddress')
AllocateHosts = Action('AllocateHosts')
ApplySecurityGroupsToClientVpnTargetNetwork = \
    Action('ApplySecurityGroupsToClientVpnTargetNetwork')
AssignIpv6Addresses = Action('AssignIpv6Addresses')
AssignPrivateIpAddresses = Action('AssignPrivateIpAddresses')
AssociateAddress = Action('AssociateAddress')
AssociateClientVpnTargetNetwork = \
    Action('AssociateClientVpnTargetNetwork')
AssociateDhcpOptions = Action('AssociateDhcpOptions')
AssociateIamInstanceProfile = Action('AssociateIamInstanceProfile')
AssociateRouteTable = Action('AssociateRouteTable')
AssociateSubnetCidrBlock = Action('AssociateSubnetCidrBlock')
AssociateTransitGatewayRouteTable = \
    Action('AssociateTransitGatewayRouteTable')
AssociateVpcCidrBlock = Action('AssociateVpcCidrBlock')
AttachClassicLinkVpc = Action('AttachClassicLinkVpc')
AttachInternetGateway = Action('AttachInternetGateway')
AttachNetworkInterface = Action('AttachNetworkInterface')
AttachVolume = Action('AttachVolume')
AttachVpnGateway = Action('AttachVpnGateway')
AuthorizeClientVpnIngress = Action('AuthorizeClientVpnIngress')
AuthorizeSecurityGroupEgress = Action('AuthorizeSecurityGroupEgress')
AuthorizeSecurityGroupIngress = Action('AuthorizeSecurityGroupIngress')
BundleInstance = Action('BundleInstance')
CancelBundleTask = Action('CancelBundleTask')
CancelCapacityReservation = Action('CancelCapacityReservation')
CancelConversionTask = Action('CancelConversionTask')
CancelExportTask = Action('CancelExportTask')
CancelImportTask = Action('CancelImportTask')
CancelReservedInstancesListing = Action('CancelReservedInstancesListing')
CancelSpotFleetRequests = Action('CancelSpotFleetRequests')
CancelSpotInstanceRequests = Action('CancelSpotInstanceRequests')
ConfirmProductInstance = Action('ConfirmProductInstance')
CopyFpgaImage = Action('CopyFpgaImage')
CopyImage = Action('CopyImage')
CopySnapshot = Action('CopySnapshot')
CreateCapacityReservation = Action('CreateCapacityReservation')
CreateClientVpnEndpoint = Action('CreateClientVpnEndpoint')
CreateClientVpnRoute = Action('CreateClientVpnRoute')
CreateCustomerGateway = Action('CreateCustomerGateway')
CreateDefaultSubnet = Action('CreateDefaultSubnet')
CreateDefaultVpc = Action('CreateDefaultVpc')
CreateDhcpOptions = Action('CreateDhcpOptions')
CreateEgressOnlyInternetGateway = \
    Action('CreateEgressOnlyInternetGateway')
CreateFleet = Action('CreateFleet')
CreateFlowLogs = Action('CreateFlowLogs')
CreateFpgaImage = Action('CreateFpgaImage')
CreateImage = Action('CreateImage')
CreateInstanceExportTask = Action('CreateInstanceExportTask')
CreateInternetGateway = Action('CreateInternetGateway')
CreateKeyPair = Action('CreateKeyPair')
CreateLaunchTemplate = Action('CreateLaunchTemplate')
CreateLaunchTemplateVersion = Action('CreateLaunchTemplateVersion')
CreateNatGateway = Action('CreateNatGateway')
CreateNetworkAcl = Action('CreateNetworkAcl')
CreateNetworkAclEntry = Action('CreateNetworkAclEntry')
CreateNetworkInterface = Action('CreateNetworkInterface')
CreateNetworkInterfacePermission = \
    Action('CreateNetworkInterfacePermission')
CreatePlacementGroup = Action('CreatePlacementGroup')
CreateReservedInstancesListing = Action('CreateReservedInstancesListing')
CreateRoute = Action('CreateRoute')
CreateRouteTable = Action('CreateRouteTable')
CreateSecurityGroup = Action('CreateSecurityGroup')
CreateSnapshot = Action('CreateSnapshot')
CreateSnapshots = Action('CreateSnapshots')
CreateSpotDatafeedSubscription = Action('CreateSpotDatafeedSubscription')
CreateSubnet = Action('CreateSubnet')
CreateTags = Action('CreateTags')
CreateTrafficMirrorFilter = Action('CreateTrafficMirrorFilter')
CreateTrafficMirrorFilterRule = Action('CreateTrafficMirrorFilterRule')
CreateTrafficMirrorSession = Action('CreateTrafficMirrorSession')
CreateTrafficMirrorTarget = Action('CreateTrafficMirrorTarget')
CreateTransitGateway = Action('CreateTransitGateway')
CreateTransitGatewayRoute = Action('CreateTransitGatewayRoute')
CreateTransitGatewayRouteTable = Action('CreateTransitGatewayRouteTable')
CreateTransitGatewayVpcAttachment = \
    Action('CreateTransitGatewayVpcAttachment')
CreateVolume = Action('CreateVolume')
CreateVpc = Action('CreateVpc')
CreateVpcEndpoint = Action('CreateVpcEndpoint')
CreateVpcEndpointConnectionNotification = \
    Action('CreateVpcEndpointConnectionNotification')
CreateVpcEndpointServiceConfiguration = \
    Action('CreateVpcEndpointServiceConfiguration')
CreateVpcPeeringConnection = Action('CreateVpcPeeringConnection')
CreateVpnConnection = Action('CreateVpnConnection')
CreateVpnConnectionRoute = Action('CreateVpnConnectionRoute')
CreateVpnGateway = Action('CreateVpnGateway')
DeleteClientVpnEndpoint = Action('DeleteClientVpnEndpoint')
DeleteClientVpnRoute = Action('DeleteClientVpnRoute')
DeleteCustomerGateway = Action('DeleteCustomerGateway')
DeleteDhcpOptions = Action('DeleteDhcpOptions')
DeleteEgressOnlyInternetGateway = \
    Action('DeleteEgressOnlyInternetGateway')
DeleteFleets = Action('DeleteFleets')
DeleteFlowLogs = Action('DeleteFlowLogs')
DeleteFpgaImage = Action('DeleteFpgaImage')
DeleteInternetGateway = Action('DeleteInternetGateway')
DeleteKeyPair = Action('DeleteKeyPair')
DeleteLaunchTemplate = Action('DeleteLaunchTemplate')
DeleteLaunchTemplateVersions = Action('DeleteLaunchTemplateVersions')
DeleteNatGateway = Action('DeleteNatGateway')
DeleteNetworkAcl = Action('DeleteNetworkAcl')
DeleteNetworkAclEntry = Action('DeleteNetworkAclEntry')
DeleteNetworkInterface = Action('DeleteNetworkInterface')
DeleteNetworkInterfacePermission = \
    Action('DeleteNetworkInterfacePermission')
DeletePlacementGroup = Action('DeletePlacementGroup')
DeleteRoute = Action('DeleteRoute')
DeleteRouteTable = Action('DeleteRouteTable')
DeleteSecurityGroup = Action('DeleteSecurityGroup')
DeleteSnapshot = Action('DeleteSnapshot')
DeleteSpotDatafeedSubscription = Action('DeleteSpotDatafeedSubscription')
DeleteSubnet = Action('DeleteSubnet')
DeleteTags = Action('DeleteTags')
DeleteTrafficMirrorFilter = Action('DeleteTrafficMirrorFilter')
DeleteTrafficMirrorFilterRule = Action('DeleteTrafficMirrorFilterRule')
DeleteTrafficMirrorSession = Action('DeleteTrafficMirrorSession')
DeleteTrafficMirrorTarget = Action('DeleteTrafficMirrorTarget')
DeleteTransitGateway = Action('DeleteTransitGateway')
DeleteTransitGatewayRoute = Action('DeleteTransitGatewayRoute')
DeleteTransitGatewayRouteTable = Action('DeleteTransitGatewayRouteTable')
DeleteTransitGatewayVpcAttachment = \
    Action('DeleteTransitGatewayVpcAttachment')
DeleteVolume = Action('DeleteVolume')
DeleteVpc = Action('DeleteVpc')
DeleteVpcEndpointConnectionNotifications = \
    Action('DeleteVpcEndpointConnectionNotifications')
DeleteVpcEndpointServiceConfigurations = \
    Action('DeleteVpcEndpointServiceConfigurations')
DeleteVpcEndpoints = Action('DeleteVpcEndpoints')
DeleteVpcPeeringConnection = Action('DeleteVpcPeeringConnection')
DeleteVpnConnection = Action('DeleteVpnConnection')
DeleteVpnConnectionRoute = Action('DeleteVpnConnectionRoute')
DeleteVpnGateway = Action('DeleteVpnGateway')
DeprovisionByoipCidr = Action('DeprovisionByoipCidr')
DeregisterImage = Action('DeregisterImage')
DescribeAccountAttributes = Action('DescribeAccountAttributes')
DescribeAddresses = Action('DescribeAddresses')
DescribeAggregateIdFormat = Action('DescribeAggregateIdFormat')
DescribeAvailabilityZones = Action('DescribeAvailabilityZones')
DescribeBundleTasks = Action('DescribeBundleTasks')
DescribeByoipCidrs = Action('DescribeByoipCidrs')
DescribeCapacityReservations = Action('DescribeCapacityReservations')
DescribeClassicLinkInstances = Action('DescribeClassicLinkInstances')
DescribeClientVpnAuthorizationRules = \
    Action('DescribeClientVpnAuthorizationRules')
DescribeClientVpnConnections = Action('DescribeClientVpnConnections')
DescribeClientVpnEndpoints = Action('DescribeClientVpnEndpoints')
DescribeClientVpnRoutes = Action('DescribeClientVpnRoutes')
DescribeClientVpnTargetNetworks = \
    Action('DescribeClientVpnTargetNetworks')
DescribeConversionTasks = Action('DescribeConversionTasks')
DescribeCustomerGateways = Action('DescribeCustomerGateways')
DescribeDhcpOptions = Action('DescribeDhcpOptions')
DescribeEgressOnlyInternetGateways = \
    Action('DescribeEgressOnlyInternetGateways')
DescribeElasticGpus = Action('DescribeElasticGpus')
DescribeExportTasks = Action('DescribeExportTasks')
DescribeFleetHistory = Action('DescribeFleetHistory')
DescribeFleetInstances = Action('DescribeFleetInstances')
DescribeFleets = Action('DescribeFleets')
DescribeFlowLogs = Action('DescribeFlowLogs')
DescribeFpgaImageAttribute = Action('DescribeFpgaImageAttribute')
DescribeFpgaImages = Action('DescribeFpgaImages')
DescribeHostReservationOfferings = \
    Action('DescribeHostReservationOfferings')
DescribeHostReservations = Action('DescribeHostReservations')
DescribeHosts = Action('DescribeHosts')
DescribeIamInstanceProfileAssociations = \
    Action('DescribeIamInstanceProfileAssociations')
DescribeIdFormat = Action('DescribeIdFormat')
DescribeIdentityIdFormat = Action('DescribeIdentityIdFormat')
DescribeImageAttribute = Action('DescribeImageAttribute')
DescribeImages = Action('DescribeImages')
DescribeImportImageTasks = Action('DescribeImportImageTasks')
DescribeImportSnapshotTasks = Action('DescribeImportSnapshotTasks')
DescribeInstanceAttribute = Action('DescribeInstanceAttribute')
DescribeInstanceCreditSpecifications = \
    Action('DescribeInstanceCreditSpecifications')
DescribeInstanceStatus = Action('DescribeInstanceStatus')
DescribeInstances = Action('DescribeInstances')
DescribeInternetGateways = Action('DescribeInternetGateways')
DescribeKeyPairs = Action('DescribeKeyPairs')
DescribeLaunchTemplateVersions = Action('DescribeLaunchTemplateVersions')
DescribeLaunchTemplates = Action('DescribeLaunchTemplates')
DescribeMovingAddresses = Action('DescribeMovingAddresses')
DescribeNatGateways = Action('DescribeNatGateways')
DescribeNetworkAcls = Action('DescribeNetworkAcls')
DescribeNetworkInterfaceAttribute = \
    Action('DescribeNetworkInterfaceAttribute')
DescribeNetworkInterfacePermissions = \
    Action('DescribeNetworkInterfacePermissions')
DescribeNetworkInterfaces = Action('DescribeNetworkInterfaces')
DescribePlacementGroups = Action('DescribePlacementGroups')
DescribePrefixLists = Action('DescribePrefixLists')
DescribePrincipalIdFormat = Action('DescribePrincipalIdFormat')
DescribePublicIpv4Pools = Action('DescribePublicIpv4Pools')
DescribeRegions = Action('DescribeRegions')
DescribeReservedInstances = Action('DescribeReservedInstances')
DescribeReservedInstancesListings = \
    Action('DescribeReservedInstancesListings')
DescribeReservedInstancesModifications = \
    Action('DescribeReservedInstancesModifications')
DescribeReservedInstancesOfferings = \
    Action('DescribeReservedInstancesOfferings')
DescribeRouteTables = Action('DescribeRouteTables')
DescribeScheduledInstanceAvailability = \
    Action('DescribeScheduledInstanceAvailability')
DescribeScheduledInstances = Action('DescribeScheduledInstances')
DescribeSecurityGroupReferences = \
    Action('DescribeSecurityGroupReferences')
DescribeSecurityGroups = Action('DescribeSecurityGroups')
DescribeSnapshotAttribute = Action('DescribeSnapshotAttribute')
DescribeSnapshots = Action('DescribeSnapshots')
DescribeSpotDatafeedSubscription = \
    Action('DescribeSpotDatafeedSubscription')
DescribeSpotFleetInstances = Action('DescribeSpotFleetInstances')
DescribeSpotFleetRequestHistory = \
    Action('DescribeSpotFleetRequestHistory')
DescribeSpotFleetRequests = Action('DescribeSpotFleetRequests')
DescribeSpotInstanceRequests = Action('DescribeSpotInstanceRequests')
DescribeSpotPriceHistory = Action('DescribeSpotPriceHistory')
DescribeStaleSecurityGroups = Action('DescribeStaleSecurityGroups')
DescribeSubnets = Action('DescribeSubnets')
DescribeTags = Action('DescribeTags')
DescribeTrafficMirrorFilters = Action('DescribeTrafficMirrorFilters')
DescribeTrafficMirrorSessions = Action('DescribeTrafficMirrorSessions')
DescribeTrafficMirrorTargets = Action('DescribeTrafficMirrorTargets')
DescribeTransitGatewayAttachments = \
    Action('DescribeTransitGatewayAttachments')
DescribeTransitGatewayRouteTables = \
    Action('DescribeTransitGatewayRouteTables')
DescribeTransitGatewayVpcAttachments = \
    Action('DescribeTransitGatewayVpcAttachments')
DescribeTransitGateways = Action('DescribeTransitGateways')
DescribeVolumeAttribute = Action('DescribeVolumeAttribute')
DescribeVolumeStatus = Action('DescribeVolumeStatus')
DescribeVolumes = Action('DescribeVolumes')
DescribeVolumesModifications = Action('DescribeVolumesModifications')
DescribeVpcAttribute = Action('DescribeVpcAttribute')
DescribeVpcClassicLink = Action('DescribeVpcClassicLink')
DescribeVpcClassicLinkDnsSupport = \
    Action('DescribeVpcClassicLinkDnsSupport')
DescribeVpcEndpointConnectionNotifications = \
    Action('DescribeVpcEndpointConnectionNotifications')
DescribeVpcEndpointConnections = Action('DescribeVpcEndpointConnections')
DescribeVpcEndpointServiceConfigurations = \
    Action('DescribeVpcEndpointServiceConfigurations')
DescribeVpcEndpointServicePermissions = \
    Action('DescribeVpcEndpointServicePermissions')
DescribeVpcEndpointServices = Action('DescribeVpcEndpointServices')
DescribeVpcEndpoints = Action('DescribeVpcEndpoints')
DescribeVpcPeeringConnections = Action('DescribeVpcPeeringConnections')
DescribeVpcs = Action('DescribeVpcs')
DescribeVpnConnections = Action('DescribeVpnConnections')
DescribeVpnGateways = Action('DescribeVpnGateways')
DetachClassicLinkVpc = Action('DetachClassicLinkVpc')
DetachInternetGateway = Action('DetachInternetGateway')
DetachNetworkInterface = Action('DetachNetworkInterface')
DetachVolume = Action('DetachVolume')
DetachVpnGateway = Action('DetachVpnGateway')
DisableEbsEncryptionByDefault = Action('DisableEbsEncryptionByDefault')
DisableTransitGatewayRouteTablePropagation = \
    Action('DisableTransitGatewayRouteTablePropagation')
DisableVgwRoutePropagation = Action('DisableVgwRoutePropagation')
DisableVpcClassicLink = Action('DisableVpcClassicLink')
DisableVpcClassicLinkDnsSupport = \
    Action('DisableVpcClassicLinkDnsSupport')
DisassociateAddress = Action('DisassociateAddress')
DisassociateClientVpnTargetNetwork = \
    Action('DisassociateClientVpnTargetNetwork')
DisassociateIamInstanceProfile = Action('DisassociateIamInstanceProfile')
DisassociateRouteTable = Action('DisassociateRouteTable')
DisassociateSubnetCidrBlock = Action('DisassociateSubnetCidrBlock')
DisassociateTransitGatewayRouteTable = \
    Action('DisassociateTransitGatewayRouteTable')
DisassociateVpcCidrBlock = Action('DisassociateVpcCidrBlock')
EnableEbsEncryptionByDefault = Action('EnableEbsEncryptionByDefault')
EnableTransitGatewayRouteTablePropagation = \
    Action('EnableTransitGatewayRouteTablePropagation')
EnableVgwRoutePropagation = Action('EnableVgwRoutePropagation')
EnableVolumeIO = Action('EnableVolumeIO')
EnableVpcClassicLink = Action('EnableVpcClassicLink')
EnableVpcClassicLinkDnsSupport = Action('EnableVpcClassicLinkDnsSupport')
ExportClientVpnClientCertificateRevocationList = \
    Action('ExportClientVpnClientCertificateRevocationList')
ExportClientVpnClientConfiguration = \
    Action('ExportClientVpnClientConfiguration')
ExportTransitGatewayRoutes = Action('ExportTransitGatewayRoutes')
GetCapacityReservationUsage = Action('GetCapacityReservationUsage')
GetConsoleOutput = Action('GetConsoleOutput')
GetConsoleScreenshot = Action('GetConsoleScreenshot')
GetEbsDefaultKmsKeyId = Action('GetEbsDefaultKmsKeyId')
GetEbsEncryptionByDefault = Action('GetEbsEncryptionByDefault')
GetHostReservationPurchasePreview = \
    Action('GetHostReservationPurchasePreview')
GetLaunchTemplateData = Action('GetLaunchTemplateData')
GetPasswordData = Action('GetPasswordData')
GetReservedInstancesExchangeQuote = \
    Action('GetReservedInstancesExchangeQuote')
GetTransitGatewayAttachmentPropagations = \
    Action('GetTransitGatewayAttachmentPropagations')
GetTransitGatewayRouteTableAssociations = \
    Action('GetTransitGatewayRouteTableAssociations')
GetTransitGatewayRouteTablePropagations = \
    Action('GetTransitGatewayRouteTablePropagations')
ImportClientVpnClientCertificateRevocationList = \
    Action('ImportClientVpnClientCertificateRevocationList')
ImportImage = Action('ImportImage')
ImportInstance = Action('ImportInstance')
ImportKeyPair = Action('ImportKeyPair')
ImportSnapshot = Action('ImportSnapshot')
ImportVolume = Action('ImportVolume')
ModifyCapacityReservation = Action('ModifyCapacityReservation')
ModifyClientVpnEndpoint = Action('ModifyClientVpnEndpoint')
ModifyEbsDefaultKmsKeyId = Action('ModifyEbsDefaultKmsKeyId')
ModifyFleet = Action('ModifyFleet')
ModifyFpgaImageAttribute = Action('ModifyFpgaImageAttribute')
ModifyHosts = Action('ModifyHosts')
ModifyIdFormat = Action('ModifyIdFormat')
ModifyIdentityIdFormat = Action('ModifyIdentityIdFormat')
ModifyImageAttribute = Action('ModifyImageAttribute')
ModifyInstanceAttribute = Action('ModifyInstanceAttribute')
ModifyInstanceCapacityReservationAttributes = \
    Action('ModifyInstanceCapacityReservationAttributes')
ModifyInstanceCreditSpecification = \
    Action('ModifyInstanceCreditSpecification')
ModifyInstanceEventStartTime = Action('ModifyInstanceEventStartTime')
ModifyInstancePlacement = Action('ModifyInstancePlacement')
ModifyLaunchTemplate = Action('ModifyLaunchTemplate')
ModifyNetworkInterfaceAttribute = \
    Action('ModifyNetworkInterfaceAttribute')
ModifyReservedInstances = Action('ModifyReservedInstances')
ModifySnapshotAttribute = Action('ModifySnapshotAttribute')
ModifySpotFleetRequest = Action('ModifySpotFleetRequest')
ModifySubnetAttribute = Action('ModifySubnetAttribute')
ModifyTrafficMirrorFilterNetworkServices = \
    Action('ModifyTrafficMirrorFilterNetworkServices')
ModifyTrafficMirrorFilterRule = Action('ModifyTrafficMirrorFilterRule')
ModifyTrafficMirrorSession = Action('ModifyTrafficMirrorSession')
ModifyTransitGatewayVpcAttachment = \
    Action('ModifyTransitGatewayVpcAttachment')
ModifyVolume = Action('ModifyVolume')
ModifyVolumeAttribute = Action('ModifyVolumeAttribute')
ModifyVpcAttribute = Action('ModifyVpcAttribute')
ModifyVpcEndpoint = Action('ModifyVpcEndpoint')
ModifyVpcEndpointConnectionNotification = \
    Action('ModifyVpcEndpointConnectionNotification')
ModifyVpcEndpointServiceConfiguration = \
    Action('ModifyVpcEndpointServiceConfiguration')
ModifyVpcEndpointServicePermissions = \
    Action('ModifyVpcEndpointServicePermissions')
ModifyVpcPeeringConnectionOptions = \
    Action('ModifyVpcPeeringConnectionOptions')
ModifyVpcTenancy = Action('ModifyVpcTenancy')
ModifyVpnConnection = Action('ModifyVpnConnection')
MonitorInstances = Action('MonitorInstances')
MoveAddressToVpc = Action('MoveAddressToVpc')
ProvisionByoipCidr = Action('ProvisionByoipCidr')
PurchaseHostReservation = Action('PurchaseHostReservation')
PurchaseReservedInstancesOffering = \
    Action('PurchaseReservedInstancesOffering')
PurchaseScheduledInstances = Action('PurchaseScheduledInstances')
RebootInstances = Action('RebootInstances')
RegisterImage = Action('RegisterImage')
RejectTransitGatewayVpcAttachment = \
    Action('RejectTransitGatewayVpcAttachment')
RejectVpcEndpointConnections = Action('RejectVpcEndpointConnections')
RejectVpcPeeringConnection = Action('RejectVpcPeeringConnection')
ReleaseAddress = Action('ReleaseAddress')
ReleaseHosts = Action('ReleaseHosts')
ReplaceIamInstanceProfileAssociation = \
    Action('ReplaceIamInstanceProfileAssociation')
ReplaceNetworkAclAssociation = Action('ReplaceNetworkAclAssociation')
ReplaceNetworkAclEntry = Action('ReplaceNetworkAclEntry')
ReplaceRoute = Action('ReplaceRoute')
ReplaceRouteTableAssociation = Action('ReplaceRouteTableAssociation')
ReplaceTransitGatewayRoute = Action('ReplaceTransitGatewayRoute')
ReportInstanceStatus = Action('ReportInstanceStatus')
RequestSpotFleet = Action('RequestSpotFleet')
RequestSpotInstances = Action('RequestSpotInstances')
ResetEbsDefaultKmsKeyId = Action('ResetEbsDefaultKmsKeyId')
ResetFpgaImageAttribute = Action('ResetFpgaImageAttribute')
ResetImageAttribute = Action('ResetImageAttribute')
ResetInstanceAttribute = Action('ResetInstanceAttribute')
ResetNetworkInterfaceAttribute = Action('ResetNetworkInterfaceAttribute')
ResetSnapshotAttribute = Action('ResetSnapshotAttribute')
RestoreAddressToClassic = Action('RestoreAddressToClassic')
RevokeClientVpnIngress = Action('RevokeClientVpnIngress')
RevokeSecurityGroupEgress = Action('RevokeSecurityGroupEgress')
RevokeSecurityGroupIngress = Action('RevokeSecurityGroupIngress')
RunInstances = Action('RunInstances')
RunScheduledInstances = Action('RunScheduledInstances')
SearchTransitGatewayRoutes = Action('SearchTransitGatewayRoutes')
SendDiagnosticInterrupt = Action('SendDiagnosticInterrupt')
StartInstances = Action('StartInstances')
StopInstances = Action('StopInstances')
TerminateClientVpnConnections = Action('TerminateClientVpnConnections')
TerminateInstances = Action('TerminateInstances')
UnassignIpv6Addresses = Action('UnassignIpv6Addresses')
UnassignPrivateIpAddresses = Action('UnassignPrivateIpAddresses')
UnmonitorInstances = Action('UnmonitorInstances')
UpdateSecurityGroupRuleDescriptionsEgress = \
    Action('UpdateSecurityGroupRuleDescriptionsEgress')
UpdateSecurityGroupRuleDescriptionsIngress = \
    Action('UpdateSecurityGroupRuleDescriptionsIngress')
WithdrawByoipCidr = Action('WithdrawByoipCidr')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Kinesis Video Streams'
prefix = 'kinesisvideo'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateStream = Action('CreateStream')
DeleteStream = Action('DeleteStream')
DescribeStream = Action('DescribeStream')
GetDASHStreamingSessionURL = Action('GetDASHStreamingSessionURL')
GetDataEndpoint = Action('GetDataEndpoint')
GetHLSStreamingSessionURL = Action('GetHLSStreamingSessionURL')
GetMedia = Action('GetMedia')
GetMediaForFragmentList = Action('GetMediaForFragmentList')
ListFragments = Action('ListFragments')
ListStreams = Action('ListStreams')
ListTagsForStream = Action('ListTagsForStream')
PutMedia = Action('PutMedia')
TagStream = Action('TagStream')
UntagStream = Action('UntagStream')
UpdateDataRetention = Action('UpdateDataRetention')
UpdateStream = Action('UpdateStream')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon CloudSearch'
prefix = 'cloudsearch'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddTags = Action('AddTags')
BuildSuggesters = Action('BuildSuggesters')
CreateDomain = Action('CreateDomain')
DefineAnalysisScheme = Action('DefineAnalysisScheme')
DefineExpression = Action('DefineExpression')
DefineIndexField = Action('DefineIndexField')
DefineIndexFields = Action('DefineIndexFields')
DefineSuggester = Action('DefineSuggester')
DeleteAnalysisScheme = Action('DeleteAnalysisScheme')
DeleteDomain = Action('DeleteDomain')
DeleteExpression = Action('DeleteExpression')
DeleteIndexField = Action('DeleteIndexField')
DeleteSuggester = Action('DeleteSuggester')
DescribeAnalysisSchemes = Action('DescribeAnalysisSchemes')
DescribeAvailabilityOptions = Action('DescribeAvailabilityOptions')
DescribeDomains = Action('DescribeDomains')
DescribeExpressions = Action('DescribeExpressions')
DescribeIndexFields = Action('DescribeIndexFields')
DescribeScalingParameters = Action('DescribeScalingParameters')
DescribeServiceAccessPolicies = Action('DescribeServiceAccessPolicies')
DescribeSuggesters = Action('DescribeSuggesters')
IndexDocuments = Action('IndexDocuments')
ListDomainNames = Action('ListDomainNames')
ListTags = Action('ListTags')
RemoveTags = Action('RemoveTags')
UpdateAvailabilityOptions = Action('UpdateAvailabilityOptions')
UpdateScalingParameters = Action('UpdateScalingParameters')
UpdateServiceAccessPolicies = Action('UpdateServiceAccessPolicies')
document = Action('document')
search = Action('search')
suggest = Action('suggest')



from setuptools import setup, find_packages

setup(
    name='awacs',
    version='0.9.7',
    description="AWS Access Policy Language creation library",
    author="Mark Peek",
    author_email="mark@peek.org",
    url="https://github.com/cloudtools/awacs",
    license="New BSD license",
    packages=find_packages(),
    test_suite="tests",
    use_2to3=True,
    requires=['slimit'],
    python_requires=">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",

        "License :: OSI Approved :: BSD License",

        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX :: BSD",
        "Operating System :: POSIX :: Linux",

        "Programming Language :: Python",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 2.7",
    ],
)



from awacs.aws import Allow, AWSPrincipal, Condition
from awacs.aws import Policy, Statement
from awacs.aws import DateGreaterThan, DateLessThan, IpAddress
import awacs.sqs as sqs


region = 'us-east-1'
account = '444455556666'

pd = Policy(
    Id="Queue1_Policy_UUID",
    Statement=[
        Statement(
            Sid="Queue1_SendMessage",
            Effect=Allow,
            Principal=AWSPrincipal("111122223333"),
            Action=[sqs.SendMessage],
            Resource=[sqs.ARN(region, account, "queue1"), ],
            Condition=Condition([
                DateGreaterThan("aws:CurrentTime", "2010-08-16T12:00:00Z"),
                DateLessThan("aws:CurrentTime", "2010-08-16T15:00:00Z"),
                IpAddress("aws:SourceIp", ["192.0.2.0/24", "203.0.113.0/24"]),
            ]),
        ),
    ],
)
print(pd.to_json())



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Trusted Advisor'
prefix = 'trustedadvisor'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


DescribeAccount = Action('DescribeAccount')
DescribeAccountAccess = Action('DescribeAccountAccess')
DescribeCheckItems = Action('DescribeCheckItems')
DescribeCheckRefreshStatuses = Action('DescribeCheckRefreshStatuses')
DescribeCheckSummaries = Action('DescribeCheckSummaries')
DescribeChecks = Action('DescribeChecks')
DescribeNotificationPreferences = \
    Action('DescribeNotificationPreferences')
ExcludeCheckItems = Action('ExcludeCheckItems')
IncludeCheckItems = Action('IncludeCheckItems')
RefreshCheck = Action('RefreshCheck')
SetAccountAccess = Action('SetAccountAccess')
UpdateNotificationPreferences = Action('UpdateNotificationPreferences')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Batch'
prefix = 'batch'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CancelJob = Action('CancelJob')
CreateComputeEnvironment = Action('CreateComputeEnvironment')
CreateJobQueue = Action('CreateJobQueue')
DeleteComputeEnvironment = Action('DeleteComputeEnvironment')
DeleteJobQueue = Action('DeleteJobQueue')
DeregisterJobDefinition = Action('DeregisterJobDefinition')
DescribeComputeEnvironments = Action('DescribeComputeEnvironments')
DescribeJobDefinitions = Action('DescribeJobDefinitions')
DescribeJobQueues = Action('DescribeJobQueues')
DescribeJobs = Action('DescribeJobs')
ListJobs = Action('ListJobs')
RegisterJobDefinition = Action('RegisterJobDefinition')
SubmitJob = Action('SubmitJob')
TerminateJob = Action('TerminateJob')
UpdateComputeEnvironment = Action('UpdateComputeEnvironment')
UpdateJobQueue = Action('UpdateJobQueue')



from awacs.aws import Statement, Principal, Allow, Policy
from awacs import sts


def make_simple_assume_statement(*principals):
    return Statement(
        Principal=Principal('Service', principals),
        Effect=Allow,
        Action=[sts.AssumeRole]
    )


def make_simple_assume_policy(*principals):
    return Policy(
        Statement=[
            make_simple_assume_statement(*principals)
        ],
        Version="2012-10-17"
    )


def make_service_domain_name(service, region=''):
    """ Helper function for creating proper service domain names. """
    tld = ".com.cn" if region == "cn-north-1" else ".com"
    return "{}.amazonaws{}".format(service, tld)


def get_codedeploy_assumerole_policy(region=''):
    """ Helper function for building the AWS CodeDeploy AssumeRole Policy. """
    service = make_service_domain_name('codedeploy', region)
    return make_simple_assume_policy(service)


def get_default_assumerole_policy(region=''):
    """ Helper function for building the Default AssumeRole Policy.

    Taken from here:
        https://github.com/boto/boto/blob/develop/boto/iam/connection.py#L29
    Used to allow ec2 instances to assume the roles in their InstanceProfile.
    """
    service = make_service_domain_name('ec2', region)
    return make_simple_assume_policy(service)


def get_ecs_assumerole_policy(region=''):
    """ Helper function for building the ECS AssumeRole Policy. """
    service = make_service_domain_name('ecs', region)
    return make_simple_assume_policy(service)


def get_ecs_task_assumerole_policy(region=''):
    """ Helper function for building the AssumeRole Policy for ECS Tasks. """
    service = make_service_domain_name('ecs-tasks', region)
    return make_simple_assume_policy(service)


def get_lambda_assumerole_policy(region=''):
    """ Helper function for building the AWS Lambda AssumeRole Policy. """
    service = make_service_domain_name('lambda', region)
    return make_simple_assume_policy(service)


def get_lambda_edge_assumerole_policy(region=''):
    """ Helper function for building the AWS Lambda@Edge AssumeRole Policy. """
    return make_simple_assume_policy(*[
        make_service_domain_name(service, region)
        for service in ('lambda', 'edgelambda')
    ])


def get_application_autoscaling_assumerole_policy(region=''):
    """ Helper function for building the AWS Lambda AssumeRole Policy. """
    service = make_service_domain_name('application-autoscaling', region)
    return make_simple_assume_policy(service)



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS OpsWorks'
prefix = 'opsworks'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssignInstance = Action('AssignInstance')
AssignVolume = Action('AssignVolume')
AssociateElasticIp = Action('AssociateElasticIp')
AttachElasticLoadBalancer = Action('AttachElasticLoadBalancer')
CloneStack = Action('CloneStack')
CreateApp = Action('CreateApp')
CreateDeployment = Action('CreateDeployment')
CreateInstance = Action('CreateInstance')
CreateLayer = Action('CreateLayer')
CreateStack = Action('CreateStack')
CreateUserProfile = Action('CreateUserProfile')
DeleteApp = Action('DeleteApp')
DeleteInstance = Action('DeleteInstance')
DeleteLayer = Action('DeleteLayer')
DeleteStack = Action('DeleteStack')
DeleteUserProfile = Action('DeleteUserProfile')
DeregisterEcsCluster = Action('DeregisterEcsCluster')
DeregisterElasticIp = Action('DeregisterElasticIp')
DeregisterInstance = Action('DeregisterInstance')
DeregisterRdsDbInstance = Action('DeregisterRdsDbInstance')
DeregisterVolume = Action('DeregisterVolume')
DescribeAgentVersions = Action('DescribeAgentVersions')
DescribeApps = Action('DescribeApps')
DescribeCommands = Action('DescribeCommands')
DescribeDeployments = Action('DescribeDeployments')
DescribeEcsClusters = Action('DescribeEcsClusters')
DescribeElasticIps = Action('DescribeElasticIps')
DescribeElasticLoadBalancers = Action('DescribeElasticLoadBalancers')
DescribeInstances = Action('DescribeInstances')
DescribeLayers = Action('DescribeLayers')
DescribeLoadBasedAutoScaling = Action('DescribeLoadBasedAutoScaling')
DescribeMyUserProfile = Action('DescribeMyUserProfile')
DescribePermissions = Action('DescribePermissions')
DescribeRaidArrays = Action('DescribeRaidArrays')
DescribeRdsDbInstances = Action('DescribeRdsDbInstances')
DescribeServiceErrors = Action('DescribeServiceErrors')
DescribeStackProvisioningParameters = \
    Action('DescribeStackProvisioningParameters')
DescribeStackSummary = Action('DescribeStackSummary')
DescribeStacks = Action('DescribeStacks')
DescribeTimeBasedAutoScaling = Action('DescribeTimeBasedAutoScaling')
DescribeUserProfiles = Action('DescribeUserProfiles')
DescribeVolumes = Action('DescribeVolumes')
DetachElasticLoadBalancer = Action('DetachElasticLoadBalancer')
DisassociateElasticIp = Action('DisassociateElasticIp')
GetHostnameSuggestion = Action('GetHostnameSuggestion')
GrantAccess = Action('GrantAccess')
ListTags = Action('ListTags')
RebootInstance = Action('RebootInstance')
RegisterEcsCluster = Action('RegisterEcsCluster')
RegisterElasticIp = Action('RegisterElasticIp')
RegisterInstance = Action('RegisterInstance')
RegisterRdsDbInstance = Action('RegisterRdsDbInstance')
RegisterVolume = Action('RegisterVolume')
SetLoadBasedAutoScaling = Action('SetLoadBasedAutoScaling')
SetPermission = Action('SetPermission')
SetTimeBasedAutoScaling = Action('SetTimeBasedAutoScaling')
StartInstance = Action('StartInstance')
StartStack = Action('StartStack')
StopInstance = Action('StopInstance')
StopStack = Action('StopStack')
TagResource = Action('TagResource')
UnassignInstance = Action('UnassignInstance')
UnassignVolume = Action('UnassignVolume')
UntagResource = Action('UntagResource')
UpdateApp = Action('UpdateApp')
UpdateElasticIp = Action('UpdateElasticIp')
UpdateInstance = Action('UpdateInstance')
UpdateLayer = Action('UpdateLayer')
UpdateMyUserProfile = Action('UpdateMyUserProfile')
UpdateRdsDbInstance = Action('UpdateRdsDbInstance')
UpdateStack = Action('UpdateStack')
UpdateUserProfile = Action('UpdateUserProfile')
UpdateVolume = Action('UpdateVolume')



import unittest

from awacs.iam import ARN


class TestARN(unittest.TestCase):
    def test_aws(self):
        arn = ARN("root", "us-east-1", "account")
        self.assertEqual(arn.JSONrepr(), "arn:aws:iam::account:root")

    def test_cn(self):
        arn = ARN("root", "cn-north-1", "account")
        self.assertEqual(arn.JSONrepr(), "arn:aws-cn:iam::account:root")

    def test_gov(self):
        arn = ARN("root", "us-gov-west-1", "account")
        self.assertEqual(arn.JSONrepr(), "arn:aws-us-gov:iam::account:root")
